==> kdevelop-4.6.90.tar.xz: kdevelop-4.6.90/kdeintegration/kdeprovider/kdevkdeprovider.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=kde
Exec=blubb
Comment=This plugin helps to obtain KDE projects
Comment[bs]=Ovaj dodatak omogućava dobijanje KDE projekada
Comment[ca]=Aquest connector ajuda a obtenir els projectes KDE
Comment[ca@valencia]=Este connector ajuda a obtindre els projectes KDE
Comment[da]=Dette plugin hjælper med at hente KDE-projekter
Comment[de]=Dieses Modul hilft dabei KDE-Projekte zu beziehen
Comment[el]=Αυτό το πρόσθετο βοηθάει στην απόκτηση έργων KDE
Comment[en_GB]=This plugin helps to obtain KDE projects
Comment[es]=Este complemento ayuda a obtener proyectos de KDE
Comment[et]=See plugin aitab hankida KDE projekte
Comment[fi]=Tämä liitännäinen auttaa KDE-projektien hakemisessa
Comment[fr]=Ce module externe permet d'obtenir des projets KDE
Comment[gl]=Este engadido permite obter proxectos de KDE
Comment[hu]=Ez a bővítmény segít KDE projektek megszerzésében
Comment[it]=Questa estensione consente di ottenere progetti di KDE
Comment[ja]=このプラグインで KDE のプロジェクトが取得できます
Comment[kk]=KDE жобаларын жүктеп алуға көмек плагині
Comment[km]=កម្មវិធី​ជំនួយ​នេះ​ជា​ជំនួយ​ដើម្បី​ទទួល​បាន​គម្រោង​របស់​ KDE
Comment[nb]=Dette programtillegget hjelper til med å skaffe KDE-prosjekter
Comment[nds]=Dit Moduul ünnerstütt Di bi't Halen vun KDE-Projekten.
Comment[nl]=Deze plugin helpt om KDE-projects te verkrijgen
Comment[pl]=Wtyczka ta pozwala na uzyskiwanie projektów KDE
Comment[pt]=Este 'plugin' ajuda a obter projectos do KDE
Comment[pt_BR]=Este plugin ajuda a obter projetos do KDE
Comment[ru]=Это расширение помогает получать код проектов KDE
Comment[sk]=Tento modul pomáha získavať KDE projekty
Comment[sl]=Ta vstavek pomaga pri pridobivanju KDE-jevih projektov
Comment[sv]=Insticksprogrammet hjälper till att erhålla KDE-projekt
Comment[tr]=Bu eklenti KDE projelerini edinmeye ayardım eder
Comment[ug]=بۇ قىستۇرما KDE قۇرۇلۇشلىرىنى ئېلىشقا ياردەم قىلىدۇ
Comment[uk]=За допомогою цього додатка можна звантажувати проекти KDE
Comment[x-test]=xxThis plugin helps to obtain KDE projectsxx
Comment[zh_CN]=此插件帮助您获取 KDE 项目
Comment[zh_TW]=此外掛程式能協助您取得 KDE 專案
Name=KDE Provider
Name[bs]=KDE pružalac
Name[ca]=Proveïdor del KDE
Name[ca@valencia]=Proveïdor del KDE
Name[cs]=Poskytovatel KDE
Name[da]=KDE-udbyder
Name[de]=KDE-Provider
Name[el]=Πάροχος KDE
Name[en_GB]=KDE Provider
Name[es]=Proveedor de KDE
Name[et]=KDE Provider
Name[fi]=KDE-tarjoaja
Name[fr]=Fournisseur KDE
Name[ga]=Soláthraí KDE
Name[gl]=Provedor do KDE
Name[hu]=KDE szolgáltató
Name[it]=Fornitore di KDE
Name[kk]=KDE таратушысы
Name[km]=ក្រុមហ៊ុម​ផ្ដល់ KDE
Name[nb]=KDE-leverandør
Name[nds]=KDE-Anbeder
Name[nl]=KDE-leverancier
Name[pl]=Dostawca KDE
Name[pt]=Fornecedor do KDE
Name[pt_BR]=Fornecedor do KDE
Name[ru]=Поставщик проектов KDE
Name[sk]=Poskytovateľ KDE
Name[sl]=KDE-jev ponudnik
Name[sv]=KDE-leverantör
Name[tr]=KDE Sağlayıcı
Name[ug]=KDE تەمىنلىگۈچى
Name[uk]=Надавач даних KDE
Name[x-test]=xxKDE Providerxx
Name[zh_CN]=KDE 提供器
Name[zh_TW]=KDE 提供者
GenericName=KDE Provider
GenericName[bs]=KDE pružalac
GenericName[ca]=Proveïdor del KDE
GenericName[ca@valencia]=Proveïdor del KDE
GenericName[cs]=Poskytovatel KDE
GenericName[da]=KDE-udbyder
GenericName[de]=KDE-Provider
GenericName[el]=Πάροχος KDE
GenericName[en_GB]=KDE Provider
GenericName[es]=Proveedor de KDE
GenericName[et]=KDE Provider
GenericName[fi]=KDE-tarjoaja
GenericName[fr]=Fournisseur KDE
GenericName[ga]=Soláthraí KDE
GenericName[gl]=Provedor do KDE
GenericName[hu]=KDE szolgáltató
GenericName[it]=Fornitore di KDE
GenericName[kk]=KDE таратушысы
GenericName[km]=ក្រុមហ៊ុន​ផ្ដល់​ KDE
GenericName[nb]=KDE-leverandør
GenericName[nds]=KDE-Anbeder
GenericName[nl]=KDE-leverancier
GenericName[pl]=Dostawca KDE
GenericName[pt]=Fornecedor do KDE
GenericName[pt_BR]=Fornecedor do KDE
GenericName[ru]=Поставщик проектов KDE
GenericName[sk]=Poskytovateľ KDE
GenericName[sl]=KDE-jev ponudnik
GenericName[sv]=KDE-leverantör
GenericName[tr]=KDE Sağlayıcı
GenericName[ug]=KDE تەمىنلىگۈچى
GenericName[uk]=Надавач даних KDE
GenericName[x-test]=xxKDE Providerxx
GenericName[zh_CN]=KDE 提供器
GenericName[zh_TW]=KDE 提供者
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevkdeprovider
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDE-PluginInfo-Name=kdevkdeprovider
X-KDE-PluginInfo-Author=Aleix Pol
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Mode=GUI
X-KDevelop-Interfaces=org.kdevelop.IProjectProvider

==> kdevelop-4.7.0.tar.xz: kdevelop-4.7.0/kdeintegration/kdeprovider/kdevkdeprovider.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=kde
Exec=blubb
Comment=This plugin helps to obtain KDE projects
Comment[bs]=Ovaj dodatak omogućava dobijanje KDE projekada
Comment[ca]=Aquest connector ajuda a obtenir els projectes KDE
Comment[ca@valencia]=Este connector ajuda a obtindre els projectes KDE
Comment[da]=Dette plugin hjælper med at hente KDE-projekter
Comment[de]=Dieses Modul hilft dabei KDE-Projekte zu beziehen
Comment[el]=Αυτό το πρόσθετο βοηθάει στην απόκτηση έργων KDE
Comment[en_GB]=This plugin helps to obtain KDE projects
Comment[es]=Este complemento ayuda a obtener proyectos de KDE
Comment[et]=See plugin aitab hankida KDE projekte
Comment[fi]=Tämä liitännäinen auttaa KDE-projektien hakemisessa
Comment[fr]=Ce module externe permet d'obtenir des projets KDE
Comment[gl]=Este engadido permite obter proxectos de KDE
Comment[hu]=Ez a bővítmény segít KDE projektek megszerzésében
Comment[it]=Questa estensione consente di ottenere progetti di KDE
Comment[ja]=このプラグインで KDE のプロジェクトが取得できます
Comment[kk]=KDE жобаларын жүктеп алуға көмек плагині
Comment[km]=កម្មវិធី​ជំនួយ​នេះ​ជា​ជំនួយ​ដើម្បី​ទទួល​បាន​គម្រោង​របស់​ KDE
Comment[nb]=Dette programtillegget hjelper til med å skaffe KDE-prosjekter
Comment[nds]=Dit Moduul ünnerstütt Di bi't Halen vun KDE-Projekten.
Comment[nl]=Deze plugin helpt om KDE-projects te verkrijgen
Comment[pl]=Wtyczka ta pozwala na uzyskiwanie projektów KDE
Comment[pt]=Este 'plugin' ajuda a obter projectos do KDE
Comment[pt_BR]=Este plugin ajuda a obter projetos do KDE
Comment[ru]=Это расширение помогает получать код проектов KDE
Comment[sk]=Tento modul pomáha získavať KDE projekty
Comment[sl]=Ta vstavek pomaga pri pridobivanju KDE-jevih projektov
Comment[sv]=Insticksprogrammet hjälper till att erhålla KDE-projekt
Comment[tr]=Bu eklenti KDE projelerini edinmeye ayardım eder
Comment[ug]=بۇ قىستۇرما KDE قۇرۇلۇشلىرىنى ئېلىشقا ياردەم قىلىدۇ
Comment[uk]=За допомогою цього додатка можна звантажувати проекти KDE
Comment[x-test]=xxThis plugin helps to obtain KDE projectsxx
Comment[zh_CN]=此插件帮助您获取 KDE 项目
Comment[zh_TW]=此外掛程式能協助您取得 KDE 專案
Name=KDE Provider
Name[bs]=KDE pružalac
Name[ca]=Proveïdor del KDE
Name[ca@valencia]=Proveïdor del KDE
Name[cs]=Poskytovatel KDE
Name[da]=KDE-udbyder
Name[de]=KDE-Provider
Name[el]=Πάροχος KDE
Name[en_GB]=KDE Provider
Name[es]=Proveedor de KDE
Name[et]=KDE pakkuja
Name[fi]=KDE-tarjoaja
Name[fr]=Fournisseur KDE
Name[ga]=Soláthraí KDE
Name[gl]=Provedor do KDE
Name[hu]=KDE szolgáltató
Name[it]=Fornitore di KDE
Name[kk]=KDE таратушысы
Name[km]=ក្រុមហ៊ុម​ផ្ដល់ KDE
Name[nb]=KDE-leverandør
Name[nds]=KDE-Anbeder
Name[nl]=KDE-leverancier
Name[pl]=Dostawca KDE
Name[pt]=Fornecedor do KDE
Name[pt_BR]=Fornecedor do KDE
Name[ru]=Поставщик проектов KDE
Name[sk]=Poskytovateľ KDE
Name[sl]=KDE-jev ponudnik
Name[sv]=KDE-leverantör
Name[tr]=KDE Sağlayıcı
Name[ug]=KDE تەمىنلىگۈچى
Name[uk]=Надавач даних KDE
Name[x-test]=xxKDE Providerxx
Name[zh_CN]=KDE 提供器
Name[zh_TW]=KDE 提供者
GenericName=KDE Provider
GenericName[bs]=KDE pružalac
GenericName[ca]=Proveïdor del KDE
GenericName[ca@valencia]=Proveïdor del KDE
GenericName[cs]=Poskytovatel KDE
GenericName[da]=KDE-udbyder
GenericName[de]=KDE-Provider
GenericName[el]=Πάροχος KDE
GenericName[en_GB]=KDE Provider
GenericName[es]=Proveedor de KDE
GenericName[et]=KDE pakkuja
GenericName[fi]=KDE-tarjoaja
GenericName[fr]=Fournisseur KDE
GenericName[ga]=Soláthraí KDE
GenericName[gl]=Provedor do KDE
GenericName[hu]=KDE szolgáltató
GenericName[it]=Fornitore di KDE
GenericName[kk]=KDE таратушысы
GenericName[km]=ក្រុមហ៊ុន​ផ្ដល់​ KDE
GenericName[nb]=KDE-leverandør
GenericName[nds]=KDE-Anbeder
GenericName[nl]=KDE-leverancier
GenericName[pl]=Dostawca KDE
GenericName[pt]=Fornecedor do KDE
GenericName[pt_BR]=Fornecedor do KDE
GenericName[ru]=Поставщик проектов KDE
GenericName[sk]=Poskytovateľ KDE
GenericName[sl]=KDE-jev ponudnik
GenericName[sv]=KDE-leverantör
GenericName[tr]=KDE Sağlayıcı
GenericName[ug]=KDE تەمىنلىگۈچى
GenericName[uk]=Надавач даних KDE
GenericName[x-test]=xxKDE Providerxx
GenericName[zh_CN]=KDE 提供器
GenericName[zh_TW]=KDE 提供者
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevkdeprovider
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDE-PluginInfo-Name=kdevkdeprovider
X-KDE-PluginInfo-Author=Aleix Pol
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Mode=GUI
X-KDevelop-Interfaces=org.kdevelop.IProjectProvider
X-KDevelop-IRequired=org.kdevelop.IBasicVersionControl@kdevgit
